==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkDummyController.java <==
// java wrapper for vtkDummyController object
//

package vtk;
import vtk.*;

public class vtkDummyController extends vtkMultiProcessController
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Finalize_2();
  public void Finalize()
    { Finalize_2(); }

  private native void Finalize_3(int id0);
  public void Finalize(int id0)
    { Finalize_3(id0); }

  private native int GetLocalProcessId_4();
  public int GetLocalProcessId()
    { return GetLocalProcessId_4(); }

  private native void SingleMethodExecute_5();
  public void SingleMethodExecute()
    { SingleMethodExecute_5(); }

  private native void MultipleMethodExecute_6();
  public void MultipleMethodExecute()
    { MultipleMethodExecute_6(); }

  private native void CreateOutputWindow_7();
  public void CreateOutputWindow()
    { CreateOutputWindow_7(); }

  private native long GetCommunicator_8();
  public vtkCommunicator GetCommunicator() {
    long temp = GetCommunicator_8();

    if (temp == 0) return null;
    return (vtkCommunicator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetRMICommunicator_9();
  public vtkCommunicator GetRMICommunicator() {
    long temp = GetRMICommunicator_9();

    if (temp == 0) return null;
    return (vtkCommunicator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetCommunicator_10(vtkCommunicator id0);
  public void SetCommunicator(vtkCommunicator id0)
    { SetCommunicator_10(id0); }

  private native void SetRMICommunicator_11(vtkCommunicator id0);
  public void SetRMICommunicator(vtkCommunicator id0)
    { SetRMICommunicator_11(id0); }

  public vtkDummyController() { super(); }

  public vtkDummyController(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-aarch64.pkg.tar.xz: vtk/vtkDummyController.java <==
// java wrapper for vtkDummyController object
//

package vtk;
import vtk.*;

public class vtkDummyController extends vtkMultiProcessController
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Finalize_2();
  public void Finalize()
    { Finalize_2(); }

  private native void Finalize_3(int id0);
  public void Finalize(int id0)
    { Finalize_3(id0); }

  private native int GetLocalProcessId_4();
  public int GetLocalProcessId()
    { return GetLocalProcessId_4(); }

  private native void SingleMethodExecute_5();
  public void SingleMethodExecute()
    { SingleMethodExecute_5(); }

  private native void MultipleMethodExecute_6();
  public void MultipleMethodExecute()
    { MultipleMethodExecute_6(); }

  private native void CreateOutputWindow_7();
  public void CreateOutputWindow()
    { CreateOutputWindow_7(); }

  private native long GetRMICommunicator_8();
  public vtkCommunicator GetRMICommunicator() {
    long temp = GetRMICommunicator_8();

    if (temp == 0) return null;
    return (vtkCommunicator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCommunicator_9(vtkCommunicator id0);
  public void SetCommunicator(vtkCommunicator id0)
    { SetCommunicator_9(id0); }

  private native void SetRMICommunicator_10(vtkCommunicator id0);
  public void SetRMICommunicator(vtkCommunicator id0)
    { SetRMICommunicator_10(id0); }

  public vtkDummyController() { super(); }

  public vtkDummyController(long id) { super(id); }
  public native long   VTKInit();

}
